#
# spec file for package taskwarrior
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           taskwarrior
Version:        2.4.4
Release:        6.2
Summary:        Command-line todo list manager
License:        MIT
Group:          Productivity/Office/Organizers
Url:            http://taskwarrior.org
Source0:        http://www.taskwarrior.org/download/task-%{version}.tar.gz
#PATCH-FIX-OPENSUSE: skip the INSTALL from files intended for the installation
Patch0:         task-skip-INSTALL.patch
# PATCH-FIX-UPSTREAM taskwarrior-gcc47.patch dimstar@opensuse.org -- Fix build with gcc 4.7
Patch1:         taskwarrior-gcc47.patch
BuildRequires:  awk
BuildRequires:  cmake >= 2.8
BuildRequires:  coreutils
BuildRequires:  gcc-c++
BuildRequires:  libuuid-devel
BuildRequires:  lua-devel
# for completion
BuildRequires:  bash
BuildRequires:  vim-base
BuildRequires:  zsh
# for sync
BuildRequires:  libgnutls-devel
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
# use the name as other distributions, so 
# zypper in task will work as well
Provides:       task = %{version}-%{release}

%description
It maintains a list of tasks that you want to do, allowing you to add/remove,
and otherwise manipulate them. Task has a rich list of subcommands that allow
you to do sophisticated things with it. You'll find it has customizable
reports, charts, GTD features, Lua extensions, device synching and more.

Taskwarrior is a very active project involving people around the globe - check
often for updates.

%prep
%setup -q -n task-%{version}
%patch0 -p1
%patch1 -p1

# replace __TIME__/__DATE__ with values from source code tarball
DATE=$(/bin/date -r "%{SOURCE0}" | awk '{print $2" "$3" "$6}')
TIME=$(/bin/date -r "%{SOURCE0}" | awk '{print $4}')
sed -i src/commands/CmdDiagnostics.cpp \
 -e "s/__TIME__/\"${TIME}\"/" \
 -e "s/__DATE__/\"${DATE}\"/"

%build
%cmake

make %{?_smp_mflags}

%install
%cmake_install

# this integration stuff might be in CMakeList.txt, but ...
%define scriptsdir %{buildroot}%{_datadir}/doc/task/scripts/

install -m 0755 -d %{buildroot}%{_sysconfdir}/bash_completion.d/
mv %{scriptsdir}bash/task.sh %{buildroot}%{_sysconfdir}/bash_completion.d/

install -m 0755 -d %{buildroot}%{_datadir}/zsh/site-functions/
mv %{scriptsdir}zsh/_task %{buildroot}%{_datadir}/zsh/site-functions/
rmdir %{scriptsdir}zsh

install -m 0755 -d %{buildroot}%{_datadir}/fish/completions/
mv %{scriptsdir}fish/task.fish %{buildroot}%{_datadir}/fish/completions/
rmdir %{scriptsdir}fish

install -m 0755 -d %{buildroot}%{_datadir}/vim/site/ftdetect/
install -m 0755 -d %{buildroot}%{_datadir}/vim/site/syntax/
mv %{scriptsdir}vim/ftdetect/*vim %{buildroot}%{_datadir}/vim/site/ftdetect
mv %{scriptsdir}vim/syntax/*vim %{buildroot}%{_datadir}/vim/site/syntax
rm -rf %{scriptsdir}vim

install -m 0755 -d %{buildroot}/%{_defaultdocdir}/task
mv %{buildroot}/%{_datadir}/doc/task %{buildroot}/%{_defaultdocdir}/
rm -rf %{buildroot}/%{_datadir}/doc/task
# don't requre python/perl/ruby by default, so remove executable bit
find %{buildroot}/%{_defaultdocdir}/task -type f -exec chmod a-x {} +

%files
%defattr(-,root,root)
%doc %{_defaultdocdir}/task
%{_bindir}/task*
%{_datadir}/man/man1/task*
%{_datadir}/man/man5/task*
%config %{_sysconfdir}/bash_completion.d/task.sh
%{_datadir}/zsh/site-functions/
%dir %{_datadir}/fish/
%{_datadir}/fish/completions/
%{_datadir}/vim/site/ftdetect/task.vim
%{_datadir}/vim/site/syntax/task*.vim

%changelog
* Fri May 29 2015 mvyskocil@opensuse.org
- Update to 2.4.4 bugfix release
- Drop taskwarrior-no-return.patch
* Mon Feb 16 2015 mvyskocil@opensuse.org
- Use standard %%cmake and %%cmake_install macros
* Tue Jan 13 2015 mvyskocil@opensuse.org
- add taskwarrior-no-return.patch to shut up gcc's complaining about
  no return in non-void function
- replace __DATE__ and __TIME__ by values from source tarball
* Mon Jan 12 2015 mvyskocil@opensuse.org
- Update to 2.4.0
  - New dateformat space handling
  - New date support: 'february', extensive support for ISO-8601
  - New column formats: description.truncated_count, uda.NAME.indicator, recur.short, tag sorting
  - New color rules: color.uda.NAME.VALUE, color.label.sort, color.until
  - New virtual tags: READY, YESTERDAY, TOMORROW, PENDING, DELETED, COMPLETED, TAGGED
  - New verbosity tokens: new-uuid
  - New command: calc, _zshattributes
  - New theme: dark-gray-blue­256.theme
  - New report feature: listing breaks
  - New Python testing framework for higher-level testing
  - and many more, see http://taskwarrior.org/news/news.20150101.html
- Refresh task-skip-INSTALL.patch
- don't remove dir with bash scripts, it contains more tools
* Sat Aug 30 2014 infroma@gmail.com
- install fish completion scripts to the proper directory
* Fri Feb 28 2014 infroma@gmail.com
- added gnutls dependency for making sync with taskd available
* Sun Feb  9 2014 sleep_walker@suse.cz
- bump 2.3.0
  - New Taskserver sync capabilities.
  - New shell (tasksh) with Readline support replaces old 'task shell' command.
  - The 'dateformat' settings now default to the ISO-8601 standard of 'Y-M-D'.
  - Italian translation.
  - French translation has begun.
  - UDA fields now allow default values.
  - Now requires libuuid.
  - New virtual tags: WEEK, MONTH, YEAR, PARENT.
  - New 'remaining' format for date columns.
  - New '_get' DOM accessor helper command.
  - New task-sync(5) man page.
* Tue Apr 16 2013 mvyskocil@suse.com
- update to taskwarrior 2.2.0:
  * 'blocking' report and new color rule
  * 'statistics' shows total number of blocked/blocking tasks
  * new date shortcuts 'socm', 'eocm' - start/end of current month
  * 'collumns' command can use search strings from collumn name
  * virtual tags (BLOCKED, UNBLOCKED, BLOCKING, DUE, DUETODAY, TODAY, OVERDUE,
  ACTIVE, SCHEDULED, CHILD, UNTIL, WAITING and ANNOTATED).
  * and many more, see Changelog
- install documentation in proper SUSE place
- remove executable bit from add-ons scripts to not require perl/python/ruby
* Tue Apr 16 2013 mvyskocil@suse.com
- install zsh completion scripts to the proper directory
* Thu Sep 27 2012 mvyskocil@suse.com
- update to taskwarrior 2.1.2
  * User defined attributes
  * new 'until' date, after which they're deleted
  * allow duplication of completed tasks
  * new 'udas' subcommand
  * new 'indended' format for the 'project' attribute, defaults in 'projects'
    and 'summary' reports
  * several performance optimizations, and a lot of bugfixes
    se ChangeLog for details
* Mon Apr  2 2012 mvyskocil@suse.cz
- update to taskwarrior 2.0.0
- changes from beta4
  * 'age' component for urgency
  * improved text wrapping in utf-8
  * 'diagnostics' commands checks duplicated UUIDs
- remove external task-2.0.0.ref.pdf and install the one
  bundled in source code
- ignore already upstreamed taskwarrior-lua52.patch
* Wed Mar 21 2012 dimstar@opensuse.org
- Add taskwarrior-gcc47.patch: Fix build with gcc 4.7.
* Wed Feb 15 2012 mvyskocil@suse.cz
- fix build with lua 5.2
  * taskwarrior-lua52.patch
* Tue Nov 22 2011 mvyskocil@suse.cz
- initial packaging of taskwarrion 2.0.0 beta4 for openSUSE
